@@ -3,5 +3,5 @@
 
 """something."""
 
-from anole.fake import UserAgent
+from anole.fake import UserAgent, Name
 from anole.setting import __version__
